pub struct Balance {
pub confirmed: u64,
pub unconfirmed: i64,
}Expand description
Balance information for an address.
Fields
confirmed: u64Confirmed balance in satoshis
unconfirmed: i64Unconfirmed balance in satoshis (can be negative when spending)
Implementations
Sourceimpl Balance
impl Balance
Sourcepub fn total(&self) -> i64
pub fn total(&self) -> i64
Returns the total balance (confirmed + unconfirmed). Note: This can be less than confirmed if there are unconfirmed spends.
Sourcepub fn has_balance(&self) -> bool
pub fn has_balance(&self) -> bool
Returns true if the address has any balance (confirmed or unconfirmed).
Sourcepub fn has_unconfirmed(&self) -> bool
pub fn has_unconfirmed(&self) -> bool
Returns true if there are unconfirmed transactions.