pub struct CertPinStore { /* private fields */ }Expand description
Certificate pin store for multiple servers.
Implementations
Sourceimpl CertPinStore
impl CertPinStore
Sourcepub fn add_pin(
&mut self,
server: impl Into<String>,
fingerprint: CertFingerprint,
)
pub fn add_pin( &mut self, server: impl Into<String>, fingerprint: CertFingerprint, )
Add a certificate pin for a server.
Multiple pins can be added for the same server (for certificate rotation).
Sourcepub fn add_pin_hex(
&mut self,
server: impl Into<String>,
hex: &str,
) -> Result<()>
pub fn add_pin_hex( &mut self, server: impl Into<String>, hex: &str, ) -> Result<()>
Add a certificate pin from hex string.
Sourcepub fn verify(&self, server: &str, cert_der: &[u8]) -> bool
pub fn verify(&self, server: &str, cert_der: &[u8]) -> bool
Check if a certificate is pinned for a server.
Sourcepub fn get_pins(&self, server: &str) -> Option<&[CertFingerprint]>
pub fn get_pins(&self, server: &str) -> Option<&[CertFingerprint]>
Get all pins for a server.
Sourcepub fn remove_pins(&mut self, server: &str)
pub fn remove_pins(&mut self, server: &str)
Remove all pins for a server.
Sourcepub fn server_count(&self) -> usize
pub fn server_count(&self) -> usize
Get the number of servers with pins.